@@ -18,7 +18,7 @@ class MyForm(QtGui.QMainWindow):
         self.enableLogging = False;
         self.enableAlarm = True;
         self.enableGSMAlarm = False;
-        self.searchCellID = 0;  #modified when you choose a favorite. This variable holds the match the system searches for
+        self.searchCellID = None;  #modified when you choose a favorite. This variable holds the match the system searches for
 
         self.cellID_list_changed=False
 
@@ -103,12 +103,14 @@ class MyForm(QtGui.QMainWindow):
 
     # Change the CellID to search for when User hits "go"
     def changeCellID(self, favorite):
-        self.searchCellID = self.cellID_list[str(favorite)]
+        if self.cellID_list.__contains__(str(favorite)):
+            self.searchCellID = self.cellID_list[str(favorite)]
 
     # Enable button when user modifies the text in the comboBox
     # just to give some feedback that the two controls are linked
     def enableSaveButton(self, text):
-        self.ui.pushButtonFav.setEnabled( True )
+        if self.current_cellid != 0:
+            self.ui.pushButtonFav.setEnabled( True )
 
  #   def setAlarm(self, value):
  #       self.enableAlarm = not(self.enableAlarm)
@@ -261,6 +263,7 @@ def cell_signal_handler(*args):
             if( app_object.enableAlarm ):
                 add_two_button_alarm()
             app_object.ui.pushButtonStart.setText("Arrived at ["+app_object.cellID_name+"]. Click again to set new destination.")
+        app_object.searchCellID = None
 
     if( app_object.enableGSMAlarm and (args[3] != 0 and args[4] != 0) ):
         app_object.enableGSMAlarm = False
